==> zhongyan-manage-service-api-0.0.1-20211210.105814-53-sources.jar: cn/com/duiba/cloud/manage/service/api/handler/DataSecretHandler.java <==
package cn.com.duiba.cloud.manage.service.api.handler;

import cn.com.duiba.cloud.manage.service.api.annotation.DataSecretAnnotation;
import cn.com.duiba.cloud.manage.service.api.annotation.DataSecretFiledAnnotation;
import cn.com.duiba.cloud.manage.service.api.model.enums.AlgorithmEnum;
import cn.com.duiba.cloud.manage.service.api.utils.AesUtil;
import org.springframework.core.MethodParameter;
import org.springframework.http.HttpInputMessage;
import org.springframework.http.converter.HttpMessageConverter;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;
import org.springframework.web.servlet.mvc.method.annotation.RequestBodyAdviceAdapter;

import javax.servlet.http.HttpServletRequest;
import java.lang.reflect.Type;
import java.util.Objects;
import java.util.stream.Stream;

/**
 * @program: zhongyan-manage-service
 * @description: 数据加密处理器
 * @author: 郭云龙
 * @create: 2021-12-08 11:49
 **/
@ControllerAdvice
public class DataSecretHandler extends RequestBodyAdviceAdapter {
    //标记名称
    public static final String DATA_SECRET_ANNOTATION = "DATA_SECRET_ANNOTATION";

    private String secret = "manage2021@123edc" ;

    @Override
    public boolean supports(MethodParameter methodParameter, Type targetType, Class<? extends HttpMessageConverter<?>> converterType) {
        System.out.println("--------------");
        ServletRequestAttributes sra = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        HttpServletRequest request = sra.getRequest();
        // 判断请求是否有包装标记
        DataSecretAnnotation dataMaskingAnnotation = (DataSecretAnnotation) request.getAttribute(DATA_SECRET_ANNOTATION);
        return dataMaskingAnnotation == null ? false : true;
    }

    /**
     * 通用解密,暂时只提供AES解密
     * @param body
     * @param inputMessage
     * @param parameter
     * @param targetType
     * @param converterType
     * @return
     */
    @Override
    public Object afterBodyRead(Object body, HttpInputMessage inputMessage, MethodParameter parameter, Type targetType, Class<? extends HttpMessageConverter<?>> converterType) {

        if(Objects.isNull(body)){
            return body;
        }
        Stream.of(body.getClass().getDeclaredFields()).forEach(field -> {

            if(field.isAnnotationPresent(DataSecretFiledAnnotation.class)){
                //获取解密规则
                AlgorithmEnum algorithmEnum = field.getAnnotation(DataSecretFiledAnnotation.class).value();
                try {
                    //破坏安全性
                    field.setAccessible(true);
                    //解密
                    switch (algorithmEnum){
                        case AES:

                            //暂时只提供AES
                            field.set(body,AesUtil.decrypt(String.valueOf(field.get(body)),secret));
                        default:
                            break;
                    }
                } catch (IllegalAccessException e) {
                    e.printStackTrace();
                }
            }

        });
        return body;
    }
}

==> zhongyan-manage-service-api-3.0.16-20221214.014921-3-sources.jar: cn/com/duiba/cloud/manage/service/api/handler/DataSecretHandler.java <==
package cn.com.duiba.cloud.manage.service.api.handler;

import cn.com.duiba.cloud.manage.service.api.annotation.DataSecretAnnotation;
import cn.com.duiba.cloud.manage.service.api.annotation.DataSecretFiledAnnotation;
import cn.com.duiba.cloud.manage.service.api.config.SecretProperties;
import cn.com.duiba.cloud.manage.service.api.model.enums.AlgorithmEnum;
import cn.com.duiba.cloud.manage.service.api.utils.AESCBCUtil;
import org.springframework.core.MethodParameter;
import org.springframework.http.HttpInputMessage;
import org.springframework.http.converter.HttpMessageConverter;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;
import org.springframework.web.servlet.mvc.method.annotation.RequestBodyAdviceAdapter;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.lang.reflect.Type;
import java.util.Objects;
import java.util.stream.Stream;

/**
 * @program: zhongyan-manage-service
 * @description: 数据加密处理器
 * @author: 郭云龙
 * @create: 2021-12-08 11:49
 **/
@ControllerAdvice
public class DataSecretHandler extends RequestBodyAdviceAdapter {
    //标记名称
    public static final String DATA_SECRET_ANNOTATION = "DATA_SECRET_ANNOTATION";

    @Resource
    private SecretProperties secretProperties;

//    private String secret = "manage2021@123edc" ;

    @Override
    public boolean supports(MethodParameter methodParameter, Type targetType, Class<? extends HttpMessageConverter<?>> converterType) {
        ServletRequestAttributes sra = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        HttpServletRequest request = sra.getRequest();
        // 判断请求是否有包装标记
        DataSecretAnnotation dataMaskingAnnotation = (DataSecretAnnotation) request.getAttribute(DATA_SECRET_ANNOTATION);
        return dataMaskingAnnotation == null ? false : true;
    }

    /**
     * 通用解密,暂时只提供AES解密
     * @param body
     * @param inputMessage
     * @param parameter
     * @param targetType
     * @param converterType
     * @return
     */
    @Override
    public Object afterBodyRead(Object body, HttpInputMessage inputMessage, MethodParameter parameter, Type targetType, Class<? extends HttpMessageConverter<?>> converterType) {
        if(Objects.isNull(secretProperties.getKey())){
            return body;
        }

        if(Objects.isNull(body)){
            return body;
        }
        Stream.of(body.getClass().getDeclaredFields()).forEach(field -> {

            if(field.isAnnotationPresent(DataSecretFiledAnnotation.class)){
                //获取解密规则
                AlgorithmEnum algorithmEnum = field.getAnnotation(DataSecretFiledAnnotation.class).value();
                try {
                    //破坏安全性
                    field.setAccessible(true);
                    //解密
                    switch (algorithmEnum){
                        case AES:
                            //暂时只提供AES
                            field.set(body, AESCBCUtil.decrypt(String.valueOf(field.get(body)),secretProperties.getKey()));
                        default:
                            break;
                    }
                } catch (IllegalAccessException e) {
                    e.printStackTrace();
                }
            }

        });
        return body;
    }
}
